@@ -1,8 +1,9 @@
 /**
  * 
- * $Id: Manager.h,v 1.1 1997/07/08 17:04:11 miers Exp $
+ * $Id: Manager.h,v 1.2 2000/09/23 14:51:42 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_MANAGER_H
-#define XM_MANAGER_H
+#ifndef _XM_MANAGER_H
+#define _XM_MANAGER_H
 
 #include <Xm/Xm.h>
 
@@ -44,5 +45,4 @@ typedef struct _XmManagerClassRec *XmManagerWidgetClass;
 }
 #endif
 
-#endif
-
+#endif /* _XM_MANAGER_H */
