@@ -1,8 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/SSpinB.h,v 1.3 2000/11/13 19:48:43 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/SSpinB.h,v 1.4 2002/04/26 20:37:39 amai Exp $
  * 
- * Copyright  2000 LessTif Development Team
+ * Copyright  2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -32,6 +32,12 @@ extern "C"
 {
 #endif
 
+
+extern WidgetClass xmSimpleSpinBoxWidgetClass;
+
+typedef struct _XmSpinBoxClassRec *XmSimpleSpinBoxWidgetClass;
+typedef struct _XmSpinBoxRec *XmSimpleSpinBoxWidget;
+
 Widget XmCreateSimpleSpinBox(Widget parent, String name,
                              ArgList arglist, Cardinal argcount);
 
