@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ArrowBG.c,v 1.32 2001/05/21 08:36:51 amai Exp $
+ * $Id: ArrowBG.c,v 1.34 2003/09/15 19:11:07 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ArrowBG.c,v 1.32 2001/05/21 08:36:51 amai Exp $";
+static const char rcsid[] = "$Id: ArrowBG.c,v 1.34 2003/09/15 19:11:07 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -390,7 +390,8 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = False;
+	XGCValues	gcv;
+	Boolean		refresh_needed = False;
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRArrowDirection),
 			     ABG_Direction(new_w), new_w))
@@ -400,7 +401,9 @@ set_values(Widget old, Widget request, Widget new_w,
 			     ABG_MultiClick(new_w), new_w))
 	ABG_MultiClick(new_w) = ABG_MultiClick(old);
 
-    if (XmParentForeground(new_w) != XmParentForeground(old))
+	/* See bug #772755 : need to query the old widget's values */
+	XGetGCValues(XtDisplay(old), LabG_NormalGC(old), GCForeground, &gcv);
+	if (XmParentForeground(new_w) != gcv.foreground)
     {
 	XtReleaseGC(new_w, ABG_ArrowGC(new_w));
 	XtReleaseGC(new_w, ABG_InsensitiveGC(new_w));
@@ -641,7 +644,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
     int margin;
     Widget w = (Widget)data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     ABG_Timer(w) = 0;
 
@@ -683,7 +686,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
@@ -788,26 +791,26 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     switch (event_mask)
     {
     case XmARM_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got arm event\n"));
 	Arm(gadget, event, NULL, &num_params);
 	break;
 
     case XmACTIVATE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got activate event\n"));
 	ABG_ClickCount(gadget) = 1;
 	Activate(gadget, event, NULL, &num_params);
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got enter event\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got leave event\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
