@@ -1,6 +1,6 @@
 /*
  *
- * $Id: DropSMgr.c,v 1.35 2001/05/14 19:46:08 amai Exp $
+ * $Id: DropSMgr.c,v 1.40 2001/09/03 21:33:06 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,12 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropSMgr.c,v 1.35 2001/05/14 19:46:08 amai Exp $";
+static const char rcsid[] = "$Id: DropSMgr.c,v 1.40 2001/09/03 21:33:06 amai Exp $";
 
 #include <LTconfig.h>
 
-#include <string.h>
-
 #include <XmI/XmI.h>
 
 #include <Xm/DropSMgrP.h>
@@ -230,7 +228,7 @@ WidgetClass xmDropSiteManagerObjectClass = (WidgetClass)(&xmDropSiteManagerClass
 static void
 class_initialize(void)
 {
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
     	__FILE__, __LINE__));
 #if 0
     _XmDropSMgrObjectClassExtRec.record_type = XmQmotif;
@@ -243,7 +241,7 @@ class_part_initialize(WidgetClass widget_class)
 {
     WidgetClass sc;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
     	__FILE__, __LINE__));
     _XmFastSubclassInit(widget_class, XmDROP_SITE_MANAGER_BIT);
 
@@ -357,7 +355,7 @@ initialize(Widget request, Widget new_w,
 {
     XmDropSiteInfoRec hr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -414,7 +412,7 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:destroy(%d)\n",
     	__FILE__, __LINE__));
     DSMDestroyTable((XmDropSiteManagerObject)w);
 
@@ -427,7 +425,7 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:set_values(%d) - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -449,9 +447,9 @@ set_values(Widget old, Widget request, Widget new_w,
 static void
 updateReceiverInfo(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:updateReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:updateReceiverInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", w, "%s:updateReceiverInfo(%d) - %s\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", w, "%s:updateReceiverInfo(%d) - %s\n",
     	__FILE__, __LINE__,
     	_LtDebugEventType2String(ev->xany.type)));
 #if 1
@@ -467,7 +465,7 @@ updateReceiverInfo(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
     Atom pa;
     Widget shell = w;
 
-	DEBUGOUT(_LtDebugDebug("DND", shell, "%s:createShellInfoRec(%d)\n",
+	DEBUGOUT(_LtDebug("DND", shell, "%s:createShellInfoRec(%d)\n",
 	    __FILE__, __LINE__));
     	ri.byte_order = _XmByteOrder();
     	ri.protocol_version = DND_PROTOCOL_VERSION;
@@ -627,11 +625,11 @@ _XmICCEventToICCCallback(XmDndMessage *msg, XmDragDropCallbackStruct *cbs)
 static void
 externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 {
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug2("DRAGSINK", w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
+    DEBUGOUT(_LtDebug2("DRAGSINK", w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug0("DRAGSINK", w, "\t%s\n",
+    DEBUGOUT(_LtDebug0("DRAGSINK", w, "\t%s\n",
     	_LtDebugEventType2String(ev->xany.type)));
 
     switch (ev->xany.type)
@@ -650,14 +648,14 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 	    XmDragTopLevelClientDataStruct TLCcbs;
 
 	    	SwapMessageData(msg);
-		DEBUGOUT(_LtDebugDebug0("DRAGSINK", w, "\t%s from %s\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\t%s from %s\n",
 		    _LtDebugDragAndDropMessageType2String(msg->reason & DND_CLEAR_EVENT_TYPE),
 		    msg->reason & ~DND_CLEAR_EVENT_TYPE ? "Receiver" : "Initiator"));
-		DEBUGOUT(_LtDebugDebug0("DRAGSINK", w, "\tDS_CurDragContext %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tDS_CurDragContext %s %p\n",
 		    DS_CurDragContext(dsm) ? XtName(DS_CurDragContext(dsm)) : "NULL", DS_CurDragContext(dsm)));
-		DEBUGOUT(_LtDebugDebug0("DRAGSINK", w, "\tDisplay_ActiveDC %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tDisplay_ActiveDC %s %p\n",
 		    Display_ActiveDC(disp) ? XtName(Display_ActiveDC(disp)) : "NULL", Display_ActiveDC(disp)));
-		DEBUGOUT(_LtDebugDebug0("DRAGSINK", w, "\tXmGetDragContext %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tXmGetDragContext %s %p\n",
 		    XmGetDragContext((Widget)dsm, msg->time) ? XtName(XmGetDragContext((Widget)dsm, msg->time)) : "NULL", XmGetDragContext((Widget)dsm, msg->time)));
 
 		DnDcbs.any.reason = _XmMessageTypeToReason(msg->reason);
@@ -673,7 +671,7 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 		TLCcbs.height = XtHeight(w);
 		DS_CurDragContext(dsm) = XmGetDragContext((Widget)dsm,
 						  DnDcbs.any.timeStamp);
-		DSMUpdate(dsm, &TLCcbs, &DnDcbs);
+		DSMUpdate(dsm, (XtPointer)&TLCcbs, (XtPointer)&DnDcbs);
 	    }
 	    else
 	    {
@@ -712,7 +710,7 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
     Widget dc, disp;
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "External drag event seen\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "External drag event seen\n"));
 
     disp = XmGetXmDisplay(XtDisplay(w));
 
@@ -738,9 +736,9 @@ updateTree(Widget w, XtPointer cd, XtPointer cbs)
     Widget disp = XmGetXmDisplay(XtDisplay(w));
     XmTreeUpdateCallbackStruct *tucbs = (XmTreeUpdateCallbackStruct *) cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:updateTree(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:updateTree(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", w, "%s:updateTree(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", w, "%s:updateTree(%d)\n",
     	__FILE__, __LINE__));
 
     if (Display_DragReceiverProtocolStyle(disp) == XmDRAG_NONE)
@@ -791,7 +789,7 @@ destroyInfo(Widget w, XtPointer cd, XtPointer cbs)
 {
     Widget dsm = (Widget)cd;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:destroyInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:destroyInfo(%d)\n",
     	__FILE__, __LINE__));
     DSMDestroyInfo((XmDropSiteManagerObject)dsm, w);
 }
@@ -804,7 +802,7 @@ createShellInfoRec(XmDropSiteManagerObject dsm, Widget shell)
     XmDropSiteInfo dsi;
     XRectangle rect;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "%s:createShellInfoRec(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, shell, "%s:createShellInfoRec(%d)\n",
     	__FILE__, __LINE__));
     dsi = (XmDropSiteInfo) XtCalloc(1, sizeof(XmDropSiteInfoRec));
 
@@ -836,7 +834,7 @@ createShellInfoRec(XmDropSiteManagerObject dsm, Widget shell)
 static void
 addChildToComposite(XmDropSiteInfo pi, XmDropSiteInfo ci, short pos)
 {
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:addChildToComposite(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:addChildToComposite(%d)\n",
     	__FILE__, __LINE__));
 
     if (pi == NULL || ci == NULL)
@@ -904,7 +902,7 @@ removeChildFromComposite(XmDropSiteInfo pi, XmDropSiteInfo dsi)
 {
     int i;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:removeChildFromComposite(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:removeChildFromComposite(%d)\n",
     	__FILE__, __LINE__));
 
     if (pi->dropSiteType != XmDROP_SITE_COMPOSITE)
@@ -939,7 +937,7 @@ removeChildFromComposite(XmDropSiteInfo pi, XmDropSiteInfo dsi)
 static void
 destroyInfoRec(XmDropSiteInfo dsi, Boolean thorough)
 {
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:destroyInfoRec(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:destroyInfoRec(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi->dropSiteType == XmDROP_SITE_COMPOSITE && thorough &&
@@ -979,13 +977,13 @@ __XmDSMCreateInfo(XmDropSiteManagerObject object,
     Widget shell;
     XmDropSiteInfo info;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)object, widget,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)object, widget,
 		      "%s:__XmDSMCreateInfo(%d) - %i args\n", 
 		      __FILE__, __LINE__,
 		      num_args
 		      ));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, (Widget)object, args, num_args, False));
-    DEBUGOUT(_LtDebugDebug2("DRAGSINK", (Widget)object, widget,
+    DEBUGOUT(_LtDebug2("DRAGSINK", (Widget)object, widget,
 		      "%s:__XmDSMCreateInfo(%d) - %i args\n", 
 		      __FILE__, __LINE__,
 		      num_args
@@ -1092,7 +1090,7 @@ __XmDSMDestroyInfo(XmDropSiteManagerObject dsm,
 {
     XmDropSiteInfo dsi;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM DestroyInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM DestroyInfo\n"));
 
     dsi = (XmDropSiteInfo) DSMWidgetToInfo(dsm, widget);
 
@@ -1126,7 +1124,7 @@ __XmDSMStartUpdate(XmDropSiteManagerObject dsm,
     Widget shell = widget;
     XmDropSiteInfo info;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM StartUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM StartUpdate\n"));
 
     while (!XtIsShell(shell))
     {
@@ -1157,7 +1155,7 @@ __XmDSMRetrieveInfo(XmDropSiteManagerObject dsm,
 {
     XmDropSiteInfo info;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM RetrieveInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM RetrieveInfo\n"));
 
     if (XmIsDragContext(widget))
     {
@@ -1200,7 +1198,7 @@ __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
     Window root;
     unsigned int width, height, border;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM UpdateInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UpdateInfo\n"));
 
     dsi = (XmDropSiteInfo) DSMWidgetToInfo(dsm, widget);
 
@@ -1275,7 +1273,7 @@ __XmDSMEndUpdate(XmDropSiteManagerObject dsm,
     Widget shell;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM EndUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM EndUpdate\n"));
 
     shell = widget;
 
@@ -1324,8 +1322,8 @@ __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 {
     XmDragDropCallbackStruct *cbs = (XmDragDropCallbackStruct *) callData;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM UpdateDSM\n"));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "__XmDSMUpdateDSM\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UpdateDSM\n"));
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMUpdateDSM\n"));
 
     switch (cbs->any.reason)
     {
@@ -1347,7 +1345,7 @@ __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 	break;
 
     default:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm,
 			  "DSMUpdate default: %d\n", cbs->any.reason));
 	break;
     }
@@ -1360,7 +1358,7 @@ loc_in_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
 {
     Position tx, ty;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)dsm, dsi->dropSite, "%s:loc_in_info(%d) - %+i%+i %+i%+i\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, dsi->dropSite, "%s:loc_in_info(%d) - %+i%+i %+i%+i\n",
     	__FILE__, __LINE__,
     	x, y,
     	DS_RootX(dsm), DS_RootY(dsm)));
@@ -1372,7 +1370,7 @@ loc_in_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
 
     x -= tx;
     y -= ty;
-    DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)dsm, "\t%+i%+i\n",
+    DEBUGOUT(_LtDebug0(__FILE__, (Widget)dsm, "\t%+i%+i\n",
     	x, y));
 
     if (_XmRegionPointInRegion(dsi->region, x, y))
@@ -1393,14 +1391,14 @@ loc_to_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
     int i;
     XmDropSiteInfo child;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:loc_to_info(%d) - %+i%+i %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:loc_to_info(%d) - %+i%+i %s\n",
     	__FILE__, __LINE__,
     	x, y,
     	dsi->leaf ? "Leaf" : "Not leaf"));
 
     if (!dsi->leaf)
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)dsm, "\t%i children\n", dsi->numChildren));
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)dsm, "\t%i children\n", dsi->numChildren));
 	for (i = 0; i < dsi->numChildren; i++)
 	{
 	    child = dsi->children[i];
@@ -1448,7 +1446,7 @@ animate(XmDropSiteManagerObject dsm,
     XmDropSiteInfo dsi = (XmDropSiteInfo) DS_CurInfo(dsm);
     Widget dc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:animate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:animate(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi && dsi->animationStyle == XmDRAG_UNDER_NONE)
@@ -1473,7 +1471,7 @@ drop_site_enter(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     int nimps;
     Widget par;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:drop_site_enter(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:drop_site_enter(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_ENTER_MESSAGE;
@@ -1595,7 +1593,7 @@ drop_site_leave(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     XmDropSiteLeaveCallbackStruct dsl;
     Position x, y;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:drop_site_leave(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:drop_site_leave(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_LEAVE_MESSAGE;
@@ -1646,7 +1644,7 @@ drag_motion(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     XmDragMotionCallbackStruct dm;
     Position x, y;
 
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "%s:drag_motion(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "%s:drag_motion(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_MOTION_MESSAGE;
@@ -1736,10 +1734,10 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
     XmDropSiteInfo ndsi;
     unsigned char ps;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
     	_LtDebugDragAndDropMessageType2String(cbs->reason),
     	cbs->x, cbs->y, DS_RootX(dsm), DS_RootY(dsm)));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
     	_LtDebugDragAndDropMessageType2String(cbs->reason),
     	cbs->x, cbs->y, DS_RootX(dsm), DS_RootY(dsm)));
 
@@ -1771,9 +1769,9 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
 		drop_site_leave(dsm, cd, cbs, dsi, ps);
 	    }
 
-            DEBUGOUT(_LtDebugDebug(__FILE__, 
+            DEBUGOUT(_LtDebug(__FILE__, 
                               (Widget)dsm, "Setting dsi to %p\n", ndsi ));
-            DEBUGOUT(_LtDebugDebug("DRAGSINK", 
+            DEBUGOUT(_LtDebug("DRAGSINK", 
                               (Widget)dsm, "Setting dsi to %s\n", 
                               ndsi ? XtName(ndsi->dropSite) : "NULL"));
 	    DS_CurInfo(dsm) = (XtPointer)ndsi;
@@ -1785,7 +1783,7 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", 
+    DEBUGOUT(_LtDebug("DRAGSINK", 
                       (Widget)dsm, "Dragging on %s\n", 
                       dsi ? XtName(dsi->dropSite) : "NULL"));
     drag_motion(dsm, cd, cbs, dsi, ps);
@@ -1813,8 +1811,8 @@ __XmDSMProcessDrop(XmDropSiteManagerObject dsm,
     Cardinal nimps;
     Atom *itargs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "__XmDSMProcessDrop\n"));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessDrop %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMProcessDrop\n"));
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessDrop %s %s\n",
     	cbs->dropAction == XmDROP ? "XmDROP" : "not XmDROP",
     	cbs->dropSiteStatus == XmDROP_SITE_VALID ? "XmDROP_SITE_VALID" : "not XmDROP_SITE_VALID"));
 
@@ -1961,7 +1959,7 @@ __XmDSMOperationChanged(XmDropSiteManagerObject dsm,
     int nimps;
     Widget par;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM OperationChanged\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM OperationChanged\n"));
 
     if (DS_CurDragContext(dsm) == NULL)
     {
@@ -2095,9 +2093,9 @@ __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
     (XmDragTopLevelClientDataStruct *) clientData;
     XmDragDropCallbackStruct *cbs = (XmDragDropCallbackStruct *) callData;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "__XmDSMChangeRoot: %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMChangeRoot: %s\n",
 		      _LtDebugDragAndDropMessageType2String(cbs->any.reason)));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "__XmDSMChangeRoot: %s\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMChangeRoot: %s\n",
 		      _LtDebugDragAndDropMessageType2String(cbs->any.reason)));
 
     DS_CurTime(dsm) = cbs->any.timeStamp;
@@ -2127,7 +2125,7 @@ __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "EEEEEK!!!\n")); /* EEK! */
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "EEEEEK!!!\n")); /* EEK! */
 	    DS_DSRoot(dsm) = NULL;
 	}
 
@@ -2178,9 +2176,9 @@ __XmDSMInsertInfo(XmDropSiteManagerObject dsm,
     Widget w, parent;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
     	__FILE__, __LINE__));
 
     w = dsi->dropSite;
@@ -2249,7 +2247,7 @@ __XmDSMRemoveInfo(XmDropSiteManagerObject dsm,
     Widget w;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM RemoveInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM RemoveInfo\n"));
 
     w = dsi->dropSite;
 
@@ -2299,7 +2297,7 @@ static void
 __XmDSMSyncTree(XmDropSiteManagerObject dsm,
 		Widget shell)
 {
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)dsm, shell, "%s:__XmDSMSyncTree(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, shell, "%s:__XmDSMSyncTree(%d)\n",
     	__FILE__, __LINE__));
 }
 
@@ -2313,7 +2311,7 @@ __XmDSMGetTree(XmDropSiteManagerObject dsm,
 	       Widget shell,
 	       XtPointer dataPtr)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM GetTree\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM GetTree\n"));
 
     return 0;
 }
@@ -2327,7 +2325,7 @@ __XmDSMCreateDSInfoTable(XmDropSiteManagerObject dsm)
 {
     DSInfoTable *it;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM CreateDSInfoTable\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM CreateDSInfoTable\n"));
 
     it = (DSInfoTable *) XtCalloc(1, sizeof(DSInfoTable));
 
@@ -2347,7 +2345,7 @@ __XmDSMDestroyDSInfoTable(XmDropSiteManagerObject dsm)
 {
     DSInfoTable *it;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM DestroyDSInfoTable\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM DestroyDSInfoTable\n"));
 
     it = (DSInfoTable *) DS_DSTable(dsm);
 
@@ -2369,9 +2367,9 @@ __XmDSMRegisterInfo(XmDropSiteManagerObject dsm,
     DSInfoTable *dst;
     long hash;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(_LtDebugDebug2("DRAGSINK", (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
+    DEBUGOUT(_LtDebug2("DRAGSINK", (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi->registered)
@@ -2401,7 +2399,7 @@ __XmDSMWidgetToInfo(XmDropSiteManagerObject dsm,
     long hash;
     XmDropSiteInfo dsi;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM WidgetToInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM WidgetToInfo\n"));
 
     info = (DSInfoTable *) DS_DSTable(dsm);
 
@@ -2441,7 +2439,7 @@ __XmDSMUnregisterInfo(XmDropSiteManagerObject dsm,
     DSInfoTable *dst;
     long hash;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "DSM UnregisterInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UnregisterInfo\n"));
 
     if (!dsi->registered)
     {
@@ -2470,7 +2468,7 @@ _XmDSMUpdate(XmDropSiteManagerObject dsm,
 	     XtPointer clientData,
 	     XtPointer callData)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "_XmDSMUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "_XmDSMUpdate\n"));
 
     DSMUpdate(dsm, clientData, callData);
 }
@@ -2481,7 +2479,7 @@ _XmDSMGetTreeFromDSM(XmDropSiteManagerObject dsm,
 		     Widget shell,
 		     XtPointer dataPtr)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "_XmDSMGetTreeFromDSM\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "_XmDSMGetTreeFromDSM\n"));
 
     return DSMGetTreeFromDSM(dsm, shell, dataPtr);
 }
@@ -2493,7 +2491,7 @@ _XmDropSiteShell(Widget widget)
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmDropSiteShell\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmDropSiteShell\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2516,7 +2514,7 @@ has_ds_offspring(XmDropSiteManagerObject dsm, Widget w)
 {
     Cardinal i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)dsm, "%s:has_ds_offspring(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:has_ds_offspring(%d)\n",
     	__FILE__, __LINE__));
 
     if (!XtIsComposite(w))
@@ -2548,7 +2546,7 @@ _XmDropSiteWrapperCandidate(Widget widget)
     Widget disp = XmGetXmDisplay(XtDisplay(widget)), par;
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmDropSiteWrapperCandidate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmDropSiteWrapperCandidate\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2588,7 +2586,7 @@ _XmGetActiveDropSite(Widget widget)
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmGetActiveDropSite\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmGetActiveDropSite\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2609,7 +2607,7 @@ _XmSyncDropSiteTree(Widget shell)
     Widget disp = XmGetXmDisplay(XtDisplay(shell));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "_XmSyncDropSiteTree\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "_XmSyncDropSiteTree\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2623,7 +2621,7 @@ _XmSyncDropSiteTree(Widget shell)
 extern void
 _XmIEndUpdate(XtPointer client_data, XtIntervalId *interval_id)
 {
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:_XmIEndUpdate(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmIEndUpdate(%d)\n",
     	__FILE__, __LINE__));
 
 }
@@ -2634,7 +2632,7 @@ XmDropSiteConfigureStackingOrder(Widget widget,
 				 Widget Sibling,
 				 Cardinal stack_mode)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteConfigureStackingOrder()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteConfigureStackingOrder()\n"));
 
     /* FIX ME */
 }
@@ -2645,7 +2643,7 @@ XmDropSiteEndUpdate(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteEndUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteEndUpdate()\n"));
 
     DSMEndUpdate(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
@@ -2657,7 +2655,7 @@ XmDropSiteQueryStackingOrder(Widget widget,
 			     Widget **child_returns,
 			     Cardinal *num_child_returns)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteQueryStackingOrder()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteQueryStackingOrder()\n"));
 
     /* FIX ME */
 
@@ -2672,12 +2670,12 @@ XmDropSiteRegister(Widget widget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+    DEBUGOUT(_LtDebug(__FILE__, widget,
 		      "%s:XmDropSiteRegister(%d) - %i args\n",
 		      __FILE__, __LINE__,
 		      argcount));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, widget, arglist, argcount, False));
-    DEBUGOUT(_LtDebugDebug("DRAGSINK", widget,
+    DEBUGOUT(_LtDebug("DRAGSINK", widget,
 		      "%s:XmDropSiteRegister(%d) - %i args\n",
 		      __FILE__, __LINE__,
 		      argcount));
@@ -2695,7 +2693,7 @@ XmDropSiteRetrieve(Widget widget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteRetrieve()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteRetrieve()\n"));
 
     DSMRetrieveInfo(_XmGetDropSiteManagerObject((XmDisplay)disp),
 		    widget, arglist, argcount);
@@ -2707,7 +2705,7 @@ XmDropSiteStartUpdate(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteStartUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteStartUpdate()\n"));
 
     DSMStartUpdate(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
@@ -2718,7 +2716,7 @@ XmDropSiteUnregister(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteUnregister()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteUnregister()\n"));
 
     DSMDestroyInfo(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
@@ -2731,19 +2729,31 @@ XmDropSiteUpdate(Widget widget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteUpdate()\n"));
 
     DSMUpdateInfo(_XmGetDropSiteManagerObject((XmDisplay)disp),
 		  widget, arglist, argcount);
 }
 
-
+/* amai: this call is not within the 2.1 docs for OM ... */
 extern XmDropSiteVisuals
 XmDropSiteGetActiveVisuals(Widget widget)
 {
     /* FIX ME */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmDropSiteGetActiveVisuals()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteGetActiveVisuals()\n"));
 
     return NULL;
 }
+
+
+#if XmVERSION >= 2
+extern Boolean
+XmDropSiteRegistered(Widget w)
+{
+	/* FIX ME */
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmDropSiteRegistered()\n"));
+	return False;
+}
+#endif /* #if XmVERSION >= 2 */
