@@ -1,6 +1,6 @@
 /**
  *
- * $Id: GeoUtils.c,v 1.53 2001/05/14 19:46:09 amai Exp $
+ * $Id: GeoUtils.c,v 1.55 2001/07/31 14:38:17 sholson Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: GeoUtils.c,v 1.53 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Id: GeoUtils.c,v 1.55 2001/07/31 14:38:17 sholson Exp $";
 
 #include <LTconfig.h>
 
@@ -140,7 +140,7 @@ FitBoxesProportional(XmKidGeometry boxes, Dimension box_count,
 {
     int tmp, curx;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"FitBoxesProportional: box_count: %d box_wd: %d fill_wd: %d\n",
 		      box_count, box_wd, fill_wd));
 
@@ -217,7 +217,7 @@ FitBoxesAveraging(XmKidGeometry boxes, Dimension box_count,
     XmKidGeometry *tbox;
     int i, cnt;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		   "FitBoxesAveraging: box_count: %d box_wd: %d fill_wd: %d\n",
 		      box_count, box_wd, fill_wd));
 
@@ -277,7 +277,7 @@ _XmGeoCalcFill(Dimension width, Dimension margin, int box_count,
     Dimension tmp, tmp2;
     */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoCalcFill: %d %d %d %d %d %d %d\n",
 		      width, margin, box_count, space_end, space_between,
 		      *start, *tween));
@@ -345,7 +345,7 @@ _XmGeoLayoutSimple(XmKidGeometry boxes, XmGeoRowLayout layout,
     Dimension bw, bh;
     Position e;			/* Replacement for "end" which is unsigned */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoLayoutSimple: x,y %d %d\n", x, y));
 
     x += start;
@@ -397,7 +397,7 @@ SegmentFill(XmKidGeometry boxes, int box_count, XmGeoRowLayout layout,
     int fill_wd;
     int space_width, box_width;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
  		      "SEGMENT FILL: %d %d %d %d %d %d %d %d\n",
  		      box_count, x, width, margin, curx,
  		      max_x, end_space, space_between));
@@ -461,7 +461,7 @@ _XmGeoLayoutWrap(XmKidGeometry boxes, XmGeoRowLayout layout,
     Dimension kid_width, kid_height;
     XmKidGeometry curbox;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoLayoutWrap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoLayoutWrap\n"));
 
     left_edge = x + start;
     boxcount = 0;
@@ -551,7 +551,7 @@ _XmGeoArrangeList(XmKidGeometry boxes, XmGeoRowLayout layout,
     Dimension start, box_wd, end, tween, fill_wd;
     short adjust;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoArrangeList: x: %d y: %d wd: %d\n",
 		      x, y, width));
 
@@ -572,7 +572,7 @@ _XmGeoArrangeList(XmKidGeometry boxes, XmGeoRowLayout layout,
 
     tween = layout->space_between;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoArrangeList: fill_wd: %d width: %d\n",
 		      fill_wd, width));
 
@@ -625,7 +625,7 @@ _XmGeoStretchVertical(XmGeoMatrix geoSpec, Dimension height, Dimension maxh)
     int stretch = 0;
     short fill = 0, fill_used;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoStretchVertical\n"));
 
     layout = &(geoSpec->layouts->row);
@@ -724,7 +724,7 @@ _XmGeoFillVertical(XmGeoMatrix geoSpec, Dimension height, Dimension maxh)
     int stretch = 0;
     short fill = 0, fill_used;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoFillVertical: ht: %d maxh: %d\n",
 		      height, maxh));
 
@@ -781,7 +781,7 @@ _XmGeoAdjustBoxes(XmGeoMatrix geoSpec)
     register XmKidGeometry boxPtr;
     register XmGeoRowLayout layoutPtr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, geoSpec->composite, "_XmGeoAdjustBoxes\n"));
+    DEBUGOUT(_LtDebug(__FILE__, geoSpec->composite, "_XmGeoAdjustBoxes\n"));
 
     layoutPtr = &(geoSpec->layouts->row);
     boxPtr = geoSpec->boxes;
@@ -837,7 +837,7 @@ _XmGeoArrangeBoxes(XmGeoMatrix geoSpec,
     Dimension wd;
     Position oy;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, geoSpec->composite,
+    DEBUGOUT(_LtDebug(__FILE__, geoSpec->composite,
 		      "_XmGeoArrangeBoxes %dx%d%+d%+d\n", 
 		      pW ? *pW : 0,
 		      pH ? *pH : 0,
@@ -882,14 +882,14 @@ _XmGeoArrangeBoxes(XmGeoMatrix geoSpec,
 
 	boxPtr += layoutPtr->box_count + 1;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmGeoArrangeBoxes(2): y: %d\n", y));
 
 	layoutPtr++;
 	y += layoutPtr->space_above;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoArrangeBoxes(3): y: %d\n", y));
 
     if (layoutPtr->space_above < geoSpec->margin_h)
@@ -938,12 +938,12 @@ _XmGeoBoxesSameWidth(XmKidGeometry rowPtr,
     Dimension wd = width;
     XmKidGeometry boxes = rowPtr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoBoxesSameWidth: %d", width));
 
     if (width == 0)
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n"));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n"));
 	return 0;
     }
     else if (width >= 1)
@@ -962,17 +962,17 @@ _XmGeoBoxesSameWidth(XmKidGeometry rowPtr,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, " %i", wd));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, " %i", wd));
     boxes = rowPtr;
 
     while (boxes->kid != NULL)
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, " %s", XtName(boxes->kid)));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, " %s", XtName(boxes->kid)));
 	boxes->box.width = wd;
 	boxes++;
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n"));
     return wd;
 }
 
@@ -986,12 +986,12 @@ _XmGeoBoxesSameHeight(XmKidGeometry rowPtr,
     Dimension ht = height;
     XmKidGeometry boxes = rowPtr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoBoxesSameHeight: %d", height));
 
     if (height == 0)
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n"));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n"));
 	return 0;
     }
     else if (height >= 1)
@@ -1010,16 +1010,16 @@ _XmGeoBoxesSameHeight(XmKidGeometry rowPtr,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, " %i", ht));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, " %i", ht));
     boxes = rowPtr;
     while (boxes->kid != NULL)
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, " %s", XtName(boxes->kid)));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, " %s", XtName(boxes->kid)));
 	boxes->box.height = ht;
 	boxes++;
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n"));
     return ht;
 }
 
@@ -1037,7 +1037,7 @@ _XmGeoClearRectObjAreas(RectObj r, XWindowChanges *old)
     Widget par;			/* This really better be a composite, or we're dead */
     int full_border;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoClearRectObjAreas\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoClearRectObjAreas\n"));
 
     par = XtParent((Widget)r);
 
@@ -1065,7 +1065,7 @@ _XmGeoCount_kids(CompositeWidget c)
 {
     Cardinal i, cnt;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoCount_kids\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoCount_kids\n"));
 
     for (i = 0, cnt = 0; i < MGR_NumChildren(c); i++)
     {
@@ -1089,7 +1089,7 @@ _XmGeoGetDimensions(XmGeoMatrix geoSpec)
     Dimension curw = 0, curh = 0, fillh = 0, tmpw, tmph, roww, rowh;
     int bcount;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoGetDimensions\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoGetDimensions\n"));
 
     layoutPtr = &(geoSpec->layouts->row);
     boxPtr = geoSpec->boxes;
@@ -1186,7 +1186,7 @@ _XmGetKidGeo(Widget wid,
 	     Widget help,
 	     int geo_type)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGetKidGeo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGetKidGeo\n"));
 
     return NULL;
 }
@@ -1268,7 +1268,7 @@ _XmGeoLoadValues(Widget wid,
 
     geoResult->request_mode = CWX | CWY | CWWidth | CWHeight | CWBorderWidth;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid,
+    DEBUGOUT(_LtDebug(__FILE__, wid,
 		      "_XmGeoLoadValues: x: %d y: %d wd: %d ht: %d bdr: %d\n",
 		      geoResult->x, geoResult->y,
 		      geoResult->width, geoResult->height,
@@ -1286,7 +1286,7 @@ _XmGeoMatrixAlloc(unsigned int numRows,
 {
     XmGeoMatrix mat;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmGeoMatrixAlloc called with %d %d %d\n",
 		      numRows, numBoxes, extSize));
 
@@ -1309,7 +1309,7 @@ _XmGeoMatrixAlloc(unsigned int numRows,
 void
 _XmGeoMatrixFree(XmGeoMatrix geo_spec)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoMatrixFree\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoMatrixFree\n"));
 
     if (geo_spec->ext_destructor)
     {
@@ -1340,7 +1340,7 @@ _XmGeoMatrixGet(XmGeoMatrix geoSpec,
     register XmGeoRowLayout layoutPtr;
     register XmKidGeometry boxPtr, startBox;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, geoSpec->composite, "_XmGeoMatrixGet\n"));
+    DEBUGOUT(_LtDebug(__FILE__, geoSpec->composite, "_XmGeoMatrixGet\n"));
 
     layoutPtr = &(geoSpec->layouts->row);
     boxPtr = geoSpec->boxes;
@@ -1399,7 +1399,7 @@ _XmGeoMatrixSet(XmGeoMatrix geoSpec)
     register XmGeoRowLayout layoutPtr;
     int bcount;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmGeoMatrixSet HERE *********************\n"));
 
     if (geoSpec->set_except != NULL)
@@ -1471,7 +1471,7 @@ _XmGeoReplyYes(Widget wid,
 	       XtWidgetGeometry *desired,
 	       XtWidgetGeometry *response)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGeoReplyYes\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGeoReplyYes\n"));
 
     if (WANTS(desired, CWWidth))
     {
@@ -1526,7 +1526,7 @@ Boolean
 _XmGeoSetupKid(XmKidGeometry geo,
 	       Widget kidWid)
 {
-    DEBUGOUT(_LtDebugDebug2(__FILE__, kidWid ? XtParent(kidWid) : NULL, kidWid, "_XmGeoSetupKid\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, kidWid ? XtParent(kidWid) : NULL, kidWid, "_XmGeoSetupKid\n"));
 
     if (!kidWid)
     {
@@ -1551,7 +1551,7 @@ _XmGeometryEqual(Widget wid,
 		 XtWidgetGeometry *geoA,
 		 XtWidgetGeometry *geoB)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "_XmGeometryEqual (%s) (%s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmGeometryEqual (%s) (%s)\n",
     	_LtDebugWidgetGeometry2String(geoA),
     	_LtDebugWidgetGeometry2String(geoB)));
 
@@ -1570,7 +1570,7 @@ _XmHandleSizeUpdate(Widget w,
     Dimension wd, ht;
     XtWidgetGeometry request;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmHandleSizeUpdate %dx%d\n",XtWidth(w),XtHeight(w)));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmHandleSizeUpdate %dx%d\n",XtWidth(w),XtHeight(w)));
 
     geo = (createMatrix) (w, NULL, NULL);
 
@@ -1589,7 +1589,7 @@ _XmHandleSizeUpdate(Widget w,
 
     _XmGeoArrangeBoxes(geo, 0, 0, &wd, &ht);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmHandleSizeUpdate %dx%d %dx%d\n",XtWidth(w),XtHeight(w),wd,ht));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmHandleSizeUpdate %dx%d %dx%d\n",XtWidth(w),XtHeight(w),wd,ht));
     if (policy == XmRESIZE_GROW)
     {
 	/* check the return against the original.  If the procedure would
@@ -1644,7 +1644,7 @@ _XmHandleQueryGeometry(Widget wid,
     Dimension wd, ht;
     XmGeoMatrix cache;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmHandleQueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmHandleQueryGeometry\n"));
 
     *desired = *intended;
 
@@ -1704,7 +1704,7 @@ _XmHandleQueryGeometry(Widget wid,
     Dimension wd, ht;
     XmGeoMatrix cache;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "_XmHandleQueryGeometry - intended %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmHandleQueryGeometry - intended %s\n",
     		_LtDebugWidgetGeometry2String(intended)));
 
     if (policy == XmRESIZE_NONE)
@@ -1741,7 +1741,7 @@ _XmHandleQueryGeometry(Widget wid,
 	desired->height = ht == 0 ? 1 : ht;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "_XmHandleQueryGeometry - desired %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmHandleQueryGeometry - desired %s\n",
     		_LtDebugWidgetGeometry2String(desired)));
     return _XmGMReplyToQueryGeometry(wid, intended, desired);
 #endif
@@ -1752,7 +1752,7 @@ QueryNonePolicy(XmGeoMatrix cache, XtWidgetGeometry *geom)
 {
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, cache->composite, "QUERY NONE POLICY\n"));
+    DEBUGOUT(_LtDebug(__FILE__, cache->composite, "QUERY NONE POLICY\n"));
 
     _XmGeoMatrixGet(cache, XmGET_PREFERRED_SIZE);
 
@@ -1778,7 +1778,7 @@ QueryGrowPolicy(XmGeoMatrix cache, XtWidgetGeometry *geom)
     XtWidgetGeometry ret;
     XtGeometryResult res;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, cache->composite, "QUERY GROW POLICY\n"));
+    DEBUGOUT(_LtDebug(__FILE__, cache->composite, "QUERY GROW POLICY\n"));
 
     _XmGeoMatrixGet(cache, XmGET_PREFERRED_SIZE);
 
@@ -1876,7 +1876,7 @@ QueryAnyPolicy(XmGeoMatrix cache, XtWidgetGeometry *geom)
     XtWidgetGeometry ret;
     XtGeometryResult res;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, cache->composite, "QUERY ANY POLICY\n"));
+    DEBUGOUT(_LtDebug(__FILE__, cache->composite, "QUERY ANY POLICY\n"));
 
     _XmGeoMatrixGet(cache, XmGET_PREFERRED_SIZE);
 
@@ -1948,7 +1948,7 @@ _XmHandleGeometryManager(Widget w,
     XtGeometryResult res = XtGeometryNo;
     XtWidgetGeometry want;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator, "_XmHandleGeometryManager (%s)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, w, instigator, "_XmHandleGeometryManager (%s)\n",
     	_LtDebugWidgetGeometry2String(desired)));
 
     memset((void *)&want, 0, sizeof(XtWidgetGeometry));
@@ -1985,13 +1985,13 @@ _XmHandleGeometryManager(Widget w,
 	_XmGeoMatrixFree(cache);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "geo request for %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "geo request for %d %d\n",
 		      desired->width, desired->height));
 
     cache = (createMatrix) (w, instigator, desired);
     if (cache->no_geo_request && (cache->no_geo_request) (cache))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "geo request said no\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "geo request said no\n"));
 
 	_XmGeoMatrixFree(cache);
 
@@ -2000,7 +2000,7 @@ _XmHandleGeometryManager(Widget w,
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "querying policy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "querying policy\n"));
     switch (policy)
     {
     case XmRESIZE_NONE:
@@ -2048,6 +2048,8 @@ _XmHandleGeometryManager(Widget w,
 	    {
 		res = XtGeometryAlmost;
 		*allowed = *cache->in_layout;
+		_XmGeoMatrixFree(cache);
+		*cachePtr = NULL;
 	    }
 	}
 	else
@@ -2080,7 +2082,7 @@ _XmHandleGeometryManager(Widget w,
 		 "Geometry request returned unknow result: %d\n", res);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmHandleGeometry returns %s\n", _LtDebugGeometryResult2String(res)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmHandleGeometry returns %s\n", _LtDebugGeometryResult2String(res)));
 
     return res;
 }
@@ -2106,9 +2108,9 @@ _XmMakeGeometryRequest(Widget w,
     /* Only for warnings : */
     XtWidgetGeometry g1, g2;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmMakeGeometryRequest %s to %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmMakeGeometryRequest %s to %s\n",
 		      _LtDebugWidgetGeometry2String(desired), XtName(XtParent(w))));
-    DEBUGOUT(_LtDebugDebug("GM", w, "_XmMakeGeometryRequest %s to %s\n",
+    DEBUGOUT(_LtDebug("GM", w, "_XmMakeGeometryRequest %s to %s\n",
 		      _LtDebugWidgetGeometry2String(desired), XtName(XtParent(w))));
 
     g1 = *desired;
@@ -2138,7 +2140,7 @@ _XmMakeGeometryRequest(Widget w,
 
     answer = XtMakeGeometryRequest(w, desired, &response);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmMakeGeometryRequest : %s [%s]\n",
 		      _LtDebugGeometryResult2String(answer),
 		      _LtDebugWidgetGeometry2String(&response)));
@@ -2168,7 +2170,7 @@ _XmMakeGeometryRequest(Widget w,
 
 	answer = XtMakeGeometryRequest(w, desired, &response);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmMakeGeometryRequest (2nd request) => %s [%s]\n",
 			  _LtDebugGeometryResult2String(answer),
 			  _LtDebugWidgetGeometry2String(&response)));
@@ -2200,7 +2202,7 @@ _XmMenuBarFix(XmGeoMatrix geoSpec,
 	      XmGeoMajorLayout layoutPtr,
 	      XmKidGeometry rowPtr)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmMenuBarFix\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmMenuBarFix\n"));
 
     if (action == XmGEO_PRE_SET)
     {
@@ -2227,7 +2229,7 @@ _XmMenuBarFix(XmGeoMatrix geoSpec,
 	    XtWidgetGeometry pref;
 
 	    	XtQueryGeometry(rowPtr->kid, NULL, &pref);
-		DEBUGOUT(_LtDebugDebug(__FILE__, rowPtr->kid,
+		DEBUGOUT(_LtDebug(__FILE__, rowPtr->kid,
 			"_XmMenuBarFix(GET_PREFERRED_SIZE) %s\n",
 		        _LtDebugWidgetGeometry2String(&pref)));
 		rowPtr->box.x = 0;
@@ -2249,7 +2251,7 @@ _XmSeparatorFix(XmGeoMatrix geoSpec,
 		XmGeoMajorLayout layoutPtr,
 		XmKidGeometry rowPtr)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmSeparatorFix: action: %d\n", action));
 
     if (action == XmGEO_PRE_SET)
@@ -2335,14 +2337,14 @@ _XmSetKidGeo(XmKidGeometry kg,
 {
     while (kg->kid != NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, kg->kid,
+	DEBUGOUT(_LtDebug(__FILE__, kg->kid,
 			  "_XmSetKidGeo: x,y: %d %d w,h: %d %d b: %d\n",
 			  kg->box.x, kg->box.y, kg->box.width, kg->box.height,
 			  kg->box.border_width));
 
 	if (kg->kid == instigator)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "setting instig\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "setting instig\n"));
 	    XtX(instigator) = kg->box.x;
 	    XtY(instigator) = kg->box.y;
 	    XtWidth(instigator) = kg->box.width;
@@ -2351,7 +2353,7 @@ _XmSetKidGeo(XmKidGeometry kg,
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "setting normal\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "setting normal\n"));
 	    _XmConfigureObject(kg->kid,
 			       kg->box.x, kg->box.y,
 			       kg->box.width, kg->box.height,
@@ -2380,22 +2382,22 @@ _XmGMReplyToQueryGeometry(Widget w,
 
     if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmGMReplyToQueryGeometry(Flags "));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGMReplyToQueryGeometry(Flags "));
 	if (Wants(CWX))
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "x "));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "x "));
 	if (Wants(CWY))
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "y "));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "y "));
 	if (Wants(CWWidth))
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "w "));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "w "));
 	if (Wants(CWHeight))
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "h "));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, ")\n"));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "h "));
+	DEBUGOUT(_LtDebug0(__FILE__, w, ")\n"));
     }
 
     if (Wants(CWWidth) && request->width == reply->width &&
 	Wants(CWHeight) && request->height == reply->height)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Yes\n",
 			  request->width, request->height));
 
@@ -2405,7 +2407,7 @@ _XmGMReplyToQueryGeometry(Widget w,
     if (Wants(CWWidth) && request->width == reply->width &&
 	Wants(CWHeight) && request->height != reply->height)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Almost\n",
 			  request->width, request->height));
 
@@ -2415,7 +2417,7 @@ _XmGMReplyToQueryGeometry(Widget w,
     if (Wants(CWWidth) && request->width != reply->width &&
 	Wants(CWHeight) && request->height == reply->height)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Almost\n",
 			  request->width, request->height));
 
@@ -2425,7 +2427,7 @@ _XmGMReplyToQueryGeometry(Widget w,
     if (Wants(CWWidth) && request->width != reply->width &&
 	Wants(CWHeight) && request->height != reply->height)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Almost\n",
 			  request->width, request->height));
 
@@ -2434,7 +2436,7 @@ _XmGMReplyToQueryGeometry(Widget w,
 
     if (Wants(CWWidth) && request->width == reply->width && !Wants(CWHeight))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Yes\n",
 			  request->width, request->height));
 
@@ -2443,7 +2445,7 @@ _XmGMReplyToQueryGeometry(Widget w,
 
     if (Wants(CWHeight) && request->height == reply->height && !Wants(CWWidth))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (%d %d) => Yes\n",
 			  request->width, request->height));
 
@@ -2452,7 +2454,7 @@ _XmGMReplyToQueryGeometry(Widget w,
 
     if (reply->width == XtWidth(w) && reply->height == XtHeight(w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmGMReplyToQueryGeometry (REPLY %d %d "
 			  "ACTUAL %d %d) => No\n",
 			  reply->width, reply->height,
@@ -2461,7 +2463,7 @@ _XmGMReplyToQueryGeometry(Widget w,
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmGMReplyToQueryGeometry (REQUEST %d %d REPLY %d %d "
 		      "ACTUAL %d %d) => Almost\n",
 		      request->width, request->height,
@@ -2544,7 +2546,7 @@ _XmGMReplyToQueryGeometry(Widget w,
     }
     reply->request_mode = CWWidth | CWHeight;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:_XmGMReplyToQueryGeometry(%d)\n\trequest (%s) reply (%s) result %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmGMReplyToQueryGeometry(%d)\n\trequest (%s) reply (%s) result %s\n",
 		      __FILE__, __LINE__,
 		      _LtDebugWidgetGeometry2String(request),
 		      _LtDebugWidgetGeometry2String(reply),
@@ -2563,7 +2565,7 @@ _XmGMHandleQueryGeometry(Widget w,
 #if 0
     Dimension wantw, wanth;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGMHandleQueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGMHandleQueryGeometry\n"));
 
     *answer = *proposed;
 
@@ -2608,7 +2610,7 @@ _XmGMHandleQueryGeometry(Widget w,
 #else
     Dimension wantw, wanth;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGMHandleQueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGMHandleQueryGeometry\n"));
 
     if (resize_policy == XmRESIZE_NONE)
     {
@@ -2644,7 +2646,7 @@ _XmGMEnforceMargin(Widget w,
     Cardinal i;
     Widget child;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGMEnforceMargin\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGMEnforceMargin\n"));
 
     for (i = 0; i < MGR_NumChildren(w); i++)
     {
@@ -2693,7 +2695,7 @@ _XmGMCalcSize(Widget w, Dimension margin_w, Dimension margin_h,
     Cardinal i;
     Dimension curx = 0, cury = 0;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmGMCalcSize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGMCalcSize\n"));
 
     *retw = *reth = 0;
     for (i = 0; i < MGR_NumChildren(w); i++)
@@ -2741,13 +2743,13 @@ _XmGMDoLayout(Widget w, Dimension margin_w, Dimension margin_h,
     Dimension retw, reth;
     XtWidgetGeometry request;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmGMDoLayout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGMDoLayout\n"));
 
     _XmGMCalcSize(w, margin_w, margin_h, &retw, &reth);
 
     if (resize_policy == XmRESIZE_NONE)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "DoResize: XmRESIZE_NONE: %s\n", XtName(w)));
 	return;
     }
@@ -2774,7 +2776,7 @@ _XmGMDoLayout(Widget w, Dimension margin_w, Dimension margin_h,
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmGMDoLayout => %d %d\n",
 		      request.width, request.height));
 
@@ -2796,7 +2798,7 @@ _XmGMOverlap(Widget w, Widget instigator,
     Boolean overlap = False;
     Cardinal i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmGMOverlap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmGMOverlap\n"));
 
     /*
      * this algorithm only works with rectangles
@@ -2856,7 +2858,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
     Boolean		adjust;
     XtWidgetGeometry	instgeo;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+    DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		       "%s:_XmGMHandleGeometryManager(%d) desired (%s)\n",
 		       __FILE__, __LINE__,
 		       _LtDebugWidgetGeometry2String(desired)));
@@ -2923,10 +2925,10 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
     allowed->height = 1;
     if (x < margin_width || x + width + 2 * XtBorderWidth(instigator) > XtWidth(w) - margin_width)
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"\tx %d margin_width %d width %d XtWidth(w) %d\n",
 		x, margin_width, width, XtWidth(w)));
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
 
 	/* Reset instigator's geometry */
@@ -2941,7 +2943,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 
     if (y < margin_height || y + height + 2 * XtBorderWidth(instigator) > XtHeight(w) - margin_height)
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
 
 	/* Reset instigator's geometry */
@@ -2956,7 +2958,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 
     if (XtWidth(w) < width + 2 * (margin_width + XtBorderWidth(instigator)))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
 
 	/* Reset instigator's geometry */
@@ -2971,7 +2973,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 
     if (XtHeight(w) < height + 2 * (margin_height + XtBorderWidth(instigator)))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
 
 	/* Reset instigator's geometry */
@@ -2988,9 +2990,9 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
     if (allow_overlap == False && _XmGMOverlap(w, instigator,
 					       x, y, width, height))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, instigator,
+	DEBUGOUT(_LtDebug2(__FILE__, w, instigator,
 		"_XmGMHandleGeometryManager => NO at line %d\n", __LINE__));
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Overlap => NO\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Overlap => NO\n"));
 
 
 	/* Reset instigator's geometry */
@@ -3005,7 +3007,7 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 
     if (Wants(XtCWQueryOnly))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "QueryOnly => YES\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryOnly => YES\n"));
 
 
 	/* Reset instigator's geometry */
@@ -3018,39 +3020,39 @@ _XmGMHandleGeometryManager(Widget w, Widget instigator,
 	return XtGeometryYes;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "GeometryManager => "));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GeometryManager => "));
 
     if (Wants(CWWidth))
     {
 	XtWidth(instigator) = desired->width;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "W %d ", desired->width));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "W %d ", desired->width));
     }
     if (Wants(CWHeight))
     {
 	XtHeight(instigator) = desired->height;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "H %d ", desired->height));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "H %d ", desired->height));
     }
     if (Wants(CWX))
     {
 	XtX(instigator) = desired->x;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "X %d ", desired->x));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "X %d ", desired->x));
     }
     if (Wants(CWY))
     {
 	XtY(instigator) = desired->y;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "Y %d ", desired->y));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "Y %d ", desired->y));
     }
     if (Wants(CWBorderWidth))
     {
 	XtBorderWidth(instigator) = desired->border_width;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "BW %d ", desired->border_width));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "BW %d ", desired->border_width));
     }
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "=> YES\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, w, "=> YES\n"));
 
     return XtGeometryYes;
 #undef  Wants
