@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.116 2002/11/13 20:35:03 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.117 2003/09/15 19:11:07 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.116 2002/11/13 20:35:03 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.117 2003/09/15 19:11:07 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -1551,8 +1551,9 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = False, relayout_needed = False,
-	recalc_needed = False;
+	XGCValues	gcv;
+	Boolean		refresh_needed = False, relayout_needed = False,
+			recalc_needed = False;
 
     DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
 		      LabG_MarginRight(new_w), LabG_MarginRight(old)));
@@ -1585,8 +1586,14 @@ set_values(Widget old, Widget request, Widget new_w,
 	    recalc_needed = True;
 	}
     }
+
     /* This is a Primitive resource but we have the GC's for it... */
+    /* See bug #772755 : need to query the old widget's values */
+	XGetGCValues(XtDisplay(old), LabG_NormalGC(old), GCForeground, &gcv);
+	if (XmParentForeground(new_w) != gcv.foreground)
+/*
     if (XmParentForeground(new_w) != XmParentForeground(old))
+ */
     {
 	XtReleaseGC(new_w, LabG_NormalGC(new_w));
 	XtReleaseGC(new_w, LabG_InsensitiveGC(new_w));
