@@ -1,9 +1,9 @@
 /**
  *
- * $Id: MainW.c,v 1.63 2001/09/03 21:33:06 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/MainW.c,v 1.64 2002/07/08 17:03:05 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MainW.c,v 1.63 2001/09/03 21:33:06 amai Exp $";
+static const char rcsid[] = "$Id: MainW.c,v 1.64 2002/07/08 17:03:05 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -71,6 +71,7 @@ static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *reply);
 static void change_managed(Widget w);
 static void insert_child(Widget w);
+static void delete_child(Widget w);
 static void _XmMainWindowPreferredSize(Widget w, Widget child,
 				       XtWidgetGeometry *cg, XmMWValues * vals);
 static XtGeometryResult _XmMainWindowGeomRequest(Widget w, XmMWValues * vals);
@@ -226,7 +227,7 @@ XmMainWindowClassRec xmMainWindowClassRec = {
 	/* geometry manager */ geometry_manager, 
         /* change_managed   */ change_managed, 
         /* insert_child     */ insert_child,
-        /* delete_child     */ XtInheritDeleteChild,
+        /* delete_child     */ delete_child,
         /* extension        */ NULL,
     },
     /* Constraint class part */
@@ -2073,3 +2074,30 @@ insert_child(Widget w)
 	}
     }
 }
+
+static void
+delete_child(Widget w)
+{
+	Widget	mw = XtParent(w);
+
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w, "DeleteChild\n"));
+
+#define	superclass	(&xmScrolledWindowClassRec)
+	(*superclass->composite_class.delete_child) (w);
+#undef	superclass
+
+	if (w == MW_MenuBar(mw))
+		MW_MenuBar(mw) = NULL;
+	else if (w == MW_CommandWindow(mw))
+		MW_CommandWindow(mw) = NULL;
+	else if (w == MW_MessageWindow(mw))
+		MW_MessageWindow(mw) = NULL;
+	else if (w == SW_WorkWindow(mw))
+		SW_WorkWindow(mw) = NULL;
+	else if (w == (Widget)SW_ClipWindow(mw))
+		SW_ClipWindow(mw) = NULL;
+	else if (w == (Widget)SW_HSB(mw))
+		SW_HSB(mw) = NULL;
+	else if (w == (Widget)SW_VSB(mw))
+		SW_VSB(mw) = NULL;
+}
