@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Manager.c,v 1.108 2002/04/12 21:07:02 amai Exp $
+ * $Id: Manager.c,v 1.109 2002/05/30 14:01:14 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.108 2002/04/12 21:07:02 amai Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.109 2002/05/30 14:01:14 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -1827,6 +1827,11 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 	return;
     }
 
+    /* Yet another one - Danny 30/5/2002 */
+    if (comp->core.self != comp) {
+	_XmWarning(NULL, "XmManager _XmAcceleratorHandler: I am not myself lately\n");
+	return;
+    }
 
     /*
      * Insensitive widgets shouldn't be activated by accelerators or
