@@ -1,9 +1,9 @@
 /**
  *
- * $Id: MapEvent.c,v 1.18 2001/05/14 19:46:09 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/MapEvent.c,v 1.27 2002/04/30 22:13:01 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MapEvent.c,v 1.18 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/MapEvent.c,v 1.27 2002/04/30 22:13:01 dannybackx Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -148,6 +148,8 @@ static void ParseModSym(Value value, LateBindingsPtr *lateBindings,
 			Boolean notFlag, Value *valueP);
 
 static String PanicModeRecovery(String str);
+static String ParseRepeat(String str, int *reps, Boolean *plus,
+			  Boolean *error);
 static KeySym StringToKeySym(String str, Boolean *error);
 
 static ModifierRec modifiers[] =
@@ -399,6 +401,7 @@ FreeEventSeq(EventSeqPtr eventSeq)
     }
 }
 
+
 static void
 CompileNameValueTable(NameValueTable table)
 {
@@ -410,6 +413,7 @@ CompileNameValueTable(NameValueTable table)
     }
 }
 
+
 static int
 OrderEvents(const void *a1, const void *b1)
 {
@@ -418,6 +422,7 @@ OrderEvents(const void *a1, const void *b1)
     return ((a->signature < b->signature) ? -1 : 1);
 }
 
+
 static void
 Compile_XtEventTable(EventKeys table, Cardinal count)
 {
@@ -432,6 +437,7 @@ Compile_XtEventTable(EventKeys table, Cardinal count)
     qsort(table, count, sizeof(EventKey), OrderEvents);
 }
 
+
 static int
 OrderModifiers(const void *a1, const void *b1)
 {
@@ -439,6 +445,7 @@ OrderModifiers(const void *a1, const void *b1)
     return ((a->signature < b->signature) ? -1 : 1);
 }
 
+
 static void
 Compile_XtModifierTable(ModifierKeys table, Cardinal count)
 {
@@ -453,6 +460,7 @@ Compile_XtModifierTable(ModifierKeys table, Cardinal count)
     qsort(table, count, sizeof(ModifierRec), OrderModifiers);
 }
 
+
 static String
 PanicModeRecovery(String str)
 {
@@ -473,6 +481,7 @@ Syntax(String str, String str1)
     _XmWarning(NULL, "%s %s\n", str, str1);
 }
 
+
 static Cardinal
 LookupTMEventType(String eventStr, Boolean *error)
 {
@@ -512,6 +521,7 @@ LookupTMEventType(String eventStr, Boolean *error)
     return (Cardinal) i;
 }
 
+
 /***********************************************************************
  * _XtLookupTableSym
  * Given a table and string, it fills in the value if found and returns
@@ -535,6 +545,7 @@ _XtLookupTableSym(NameValueTable table, String name, Value *valueP)
     return FALSE;
 }
 
+
 static void
 StoreLateBindings(KeySym keysymL, Boolean notL,
 		  KeySym keysymR, Boolean notR,
@@ -595,6 +606,7 @@ StoreLateBindings(KeySym keysymL, Boolean notL,
     }
 } 
 
+
 static void
 _XtParseKeysymMod(String name, LateBindingsPtr *lateBindings,
 		  Boolean notFlag, Value *valueP, Boolean *error)
@@ -666,6 +678,7 @@ _XtLookupModifier(XrmQuark signature, LateBindingsPtr *lateBindings,
     return FALSE;
 }
 
+
 static String
 ScanIdent(String str)
 {
@@ -682,6 +695,7 @@ ScanIdent(String str)
     return str;
 }
 
+
 static String
 FetchModifierToken(String str, XrmQuark *token_return)
 {
@@ -717,6 +731,7 @@ FetchModifierToken(String str, XrmQuark *token_return)
     return str;
 }        
     
+
 static String
 ParseModifiers(String str, EventPtr event, Boolean *error)
 {
@@ -836,6 +851,7 @@ ParseModifiers(String str, EventPtr event, Boolean *error)
     return str;
 }
 
+
 static String
 ParseXtEventType(String str, EventPtr event, Cardinal *tmEventP, Boolean *error)
 {
@@ -856,6 +872,7 @@ ParseXtEventType(String str, EventPtr event, Cardinal *tmEventP, Boolean *error)
     return str;
 }
 
+
 static unsigned long
 StrToHex(String str)
 {
@@ -875,6 +892,7 @@ StrToHex(String str)
     return val;
 }
 
+
 static unsigned long
 StrToOct(String str)
 {
@@ -890,6 +908,7 @@ StrToOct(String str)
     return val;
 }
 
+
 static unsigned long
 StrToNum(String str)
 {
@@ -914,6 +933,7 @@ StrToNum(String str)
     return val;
 }
 
+
 static KeySym
 StringToKeySym(String str, Boolean *error)
 {
@@ -924,6 +944,7 @@ StringToKeySym(String str, Boolean *error)
 	return (KeySym)0;
     }
 
+
 #ifndef NOTASCII
     /* special case single character ASCII, for speed */
     if (*(str+1) == '\0')
@@ -961,7 +982,7 @@ StringToKeySym(String str, Boolean *error)
     return NoSymbol;
 }
 
-/* ARGSUSED */
+
 static void
 ParseModImmed(Value value, LateBindingsPtr *lateBindings,
 	      Boolean notFlag, Value *valueP)
@@ -969,6 +990,7 @@ ParseModImmed(Value value, LateBindingsPtr *lateBindings,
     *valueP = value;
 }
 
+
 /*
  * is only valid with keysyms that have an _L and _R in their name;
  * and ignores keysym lookup errors (i.e. assumes only valid keysyms)
@@ -985,7 +1007,7 @@ ParseModSym(Value value, LateBindingsPtr *lateBindings,
     *valueP = 0;
 }
 
-/* ARGSUSED */
+
 static String
 ParseImmed(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -995,7 +1017,7 @@ ParseImmed(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
-/* ARGSUSED */
+
 static String
 ParseAddModifier(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1010,6 +1032,7 @@ ParseAddModifier(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
+
 static String
 ParseKeyAndModifiers(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1030,7 +1053,7 @@ ParseKeyAndModifiers(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
-/*ARGSUSED*/
+
 static String
 ParseKeySym(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1093,6 +1116,7 @@ ParseKeySym(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
+
 static String
 ParseTable(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1132,7 +1156,7 @@ ParseTable(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
-/*ARGSUSED*/
+
 static String
 ParseNone(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1142,7 +1166,7 @@ ParseNone(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
-/*ARGSUSED*/
+
 static String
 ParseAtom(String str, XP closure, EventPtr event, Boolean *error)
 {
@@ -1180,12 +1204,12 @@ ParseAtom(String str, XP closure, EventPtr event, Boolean *error)
     return str;
 }
 
+
 static short buttonModifierMasks[] =
 {
     0, Button1Mask, Button2Mask, Button3Mask, Button4Mask, Button5Mask
 };
-static String ParseRepeat(String str, int *reps, Boolean *plus,
-			  Boolean *error);
+
 
 static String
 ParseEvent(String str, EventPtr event, int *reps, Boolean *plus, Boolean *error)
@@ -1258,6 +1282,7 @@ ParseEvent(String str, EventPtr event, int *reps, Boolean *plus, Boolean *error)
     return str;
 }
 
+
 static String
 ParseQuotedStringEvent(String str, EventPtr event, Boolean *error)
 {
@@ -1310,6 +1335,7 @@ static EventSeqRec timerEventRec =
     NULL
 };
 
+
 static void
 RepeatDown(EventPtr *eventP, int reps)
 {
@@ -1359,6 +1385,7 @@ RepeatDown(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatDownPlus(EventPtr *eventP, int reps)
 {
@@ -1412,6 +1439,7 @@ RepeatDownPlus(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatUp(EventPtr *eventP, int reps)
 {
@@ -1470,6 +1498,7 @@ RepeatUp(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatUpPlus(EventPtr *eventP, int reps)
 {
@@ -1523,6 +1552,7 @@ RepeatUpPlus(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatOther(EventPtr *eventP, int reps)
 {
@@ -1546,6 +1576,7 @@ RepeatOther(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatOtherPlus(EventPtr *eventP, int reps)
 {
@@ -1570,6 +1601,7 @@ RepeatOtherPlus(EventPtr *eventP, int reps)
     *eventP = event;
 }
 
+
 static void
 RepeatEvent(EventPtr *eventP, int reps, Boolean plus)
 {
@@ -1593,6 +1625,7 @@ RepeatEvent(EventPtr *eventP, int reps, Boolean plus)
     }
 }
 
+
 static String
 ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
 {
@@ -1652,6 +1685,7 @@ ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
     return str;
 }
 
+
 /***********************************************************************
  * ParseEventSeq
  * Parses the left hand side of a translation table production
@@ -1668,8 +1702,8 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
 
     while ( *str != '\0' && *str != '\n')
     {
-	static Event	nullEvent = {0, 0,0L, 0, 0L, 0L,FALSE};
-	EventPtr	event;
+	static Event nullEvent = {0, 0, (LateBindingsPtr)NULL, 0, 0L, 0L, FALSE};
+	EventPtr     event;
 
 	ScanWhitespace(str);
 
@@ -1766,26 +1800,28 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
     return str;
 }
 
+
 static void
 PrintLateBindings(LateBindingsPtr late)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "LateBindings: knot: %d pair: %d, ref: %d KeySym %04x\n",
 		      late->knot, late->pair, late->ref_count, late->keysym));
 }
 
+
 static void
 PrintEvent(Event *event)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Event: modifiers: %08x modMask: %08x late: %p\n",
 		      event->modifiers, event->modifierMask,
 		      event->lateModifiers));
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "       eventType: %08x eventCode: %08x codeMask: %08x\n",
 		      event->eventType, event->eventCode,
 		      event->eventCodeMask));
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "       standard: %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "       standard: %d\n",
 		      event->standard));
 
     if (event->lateModifiers)
@@ -1794,18 +1830,20 @@ PrintEvent(Event *event)
     }
 }
 
+
 static void
 PrintEventSeq(EventSeqPtr evs)
 {
     EventSeqPtr tmp;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "EventSequence:\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "EventSequence:\n"));
     for (tmp = evs; tmp != NULL; tmp = tmp->next)
     {
 	PrintEvent(&evs->event);
     }
 }
 
+
 static void
 _XmTransParseInit(void)
 {
@@ -1898,8 +1936,7 @@ SetLateModifier(Display *display, EventSeqPtr evs)
 
     return False;
 }
-	       
-	       
+
 
 Boolean
 _XmMapBtnEvent(String str, int *eventType,
@@ -1910,7 +1947,7 @@ _XmMapBtnEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
@@ -1954,60 +1991,113 @@ _XmMapBtnEvent(String str, int *eventType,
     return True;
 }
 
-Boolean
+
+extern Boolean
 _XmMapKeyEvent(String str, int *eventType,
 	       unsigned *keysym, unsigned int *modifiers)
 {
-    EventSeqPtr evs = NULL;
-    Boolean err = False;
+	EventSeqPtr evs = NULL;
+	Boolean err = False;
 
-    _XmTransParseInit();
+	_XmTransParseInit();
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
-    ParseEventSeq(str, &evs, &err);
+	ParseEventSeq(str, &evs, &err);
+	if (evs == NULL) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
+		FreeEventSeq(evs);
+		return False;
+	}
+
+	if (evs->next != NULL) {
+		_XmWarning(NULL, "Multiple event sequence ignored.\n");
+	}
+
+	err = SetLateModifier(_XmGetDefaultDisplay(), evs);
+	if (err) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
+		FreeEventSeq(evs);
+		return False;
+	}
+
+	PrintEventSeq(evs);
+	if (evs->event.eventType != KeyPress && evs->event.eventType != KeyRelease) {
+		FreeEventSeq(evs);
+		return False;
+	}
+
+	*eventType = evs->event.eventType;
+	*keysym = evs->event.eventCode;
+	*modifiers = evs->event.modifiers;
 
-    if (evs == NULL)
-    {
-    	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
 	FreeEventSeq(evs);
-
-	return False;
-    }
-
-    if (evs->next != NULL)
-    {
-	_XmWarning(NULL, "Multiple event sequence ignored.\n");
-    }
-
-    err = SetLateModifier(_XmGetDefaultDisplay(), evs);
-    if (err)
-    {
-    	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
-	FreeEventSeq(evs);
-
-	return False;
-    }
-
-    PrintEventSeq(evs);
-
-    if (evs->event.eventType != KeyPress &&
-	evs->event.eventType != KeyRelease)
-    {
-	FreeEventSeq(evs);
-
-	return False;
-    }
-
-    *eventType = evs->event.eventType;
-    *keysym = evs->event.eventCode;
-    *modifiers = evs->event.modifiers;
-
-    FreeEventSeq(evs);
-
-    return True;
+	return True;
 }
 
+
+#if (XmVERSION > 1)
+/*
+ * This function is documented in http://motifdeveloper.com/tips/tip15.html
+ */
+extern int
+_XmMapKeyEvents(String str, int **eventType, KeySym **keysym, Modifiers **modifiers)
+{
+	EventSeqPtr evs = NULL, e;
+	Boolean err = False;
+	char	*r;
+	int	i, cnt;
+
+	_XmTransParseInit();
+
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmMapKeyEvents(%s)\n", str));
+
+	r = ParseEventSeq(str, &evs, &err);
+	if (evs == NULL) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
+		FreeEventSeq(evs);
+		return 0;
+	}
+
+	err = SetLateModifier(_XmGetDefaultDisplay(), evs);
+	if (err) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
+		FreeEventSeq(evs);
+		return 0;
+	}
+
+	PrintEventSeq(evs);
+	if (evs->event.eventType != KeyPress && evs->event.eventType != KeyRelease) {
+		FreeEventSeq(evs);
+		return 0;
+	}
+
+	/* Count the number of elements */
+	for (cnt=0, e=evs; e; e=e->next)
+		cnt++;
+
+	/* Allocate space */
+	*eventType = (int *)XtCalloc(cnt+1, sizeof(int));
+	*keysym = (KeySym *)XtCalloc(cnt+1, sizeof(KeySym));
+	*modifiers = (Modifiers *)XtCalloc(cnt+1, sizeof(Modifiers));
+
+	/* Copy the results in the allocated space */
+	i = 0;
+	e = evs;
+	do {
+		(*eventType)[i] = e->event.eventType;
+		(*keysym)[i] = e->event.eventCode;
+		(*modifiers)[i] = e->event.modifiers;
+		i++;
+		e = e->next;
+	} while (e);
+
+	FreeEventSeq(evs);
+	return i;
+}
+#endif /* (XmVERSION > 1) */
+
+
 Boolean
 _XmMatchBtnEvent(XEvent *event, int eventType,
 		 unsigned int button, unsigned int modifiers)
@@ -2015,6 +2105,7 @@ _XmMatchBtnEvent(XEvent *event, int eventType,
     return False;
 }
 
+
 Boolean
 _XmMatchKeyEvent(XEvent *event, int eventType,
 		 unsigned int key, unsigned int modifiers)
