@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Protocols.c,v 1.13 2001/05/20 17:49:38 amai Exp $
+ * $Id: Protocols.c,v 1.14 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Protocols.c,v 1.13 2001/05/20 17:49:38 amai Exp $";
+static const char rcsid[] = "$Id: Protocols.c,v 1.14 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -167,14 +167,14 @@ WidgetClass xmProtocolClass = (WidgetClass)&xmProtocolClassRec;
 static void
 class_initialize(void)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "Protocol ClassInitialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "Protocol ClassInitialize\n"));
 }
 
 
 static void
 class_part_initialize(WidgetClass widget_class)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "Protocol ClassPartInitialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "Protocol ClassPartInitialize\n"));
 }
 
 
@@ -182,14 +182,14 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "Protocol Initialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "Protocol Initialize\n"));
 }
 
 
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Protocol Destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Protocol Destroy\n"));
 }
 
 
@@ -198,7 +198,7 @@ static Boolean
 set_values(Widget current, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "Protocol SetValues\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "Protocol SetValues\n"));
 
     return True;		/* FIX ME */
 }
@@ -218,7 +218,7 @@ __XmGetAllMgr(Widget shell)
     newman = (XmAllProtocolsMgr)_XmGetWidgetExtData(shell,
 						    XmPROTOCOL_EXTENSION);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell,
+    DEBUGOUT(_LtDebug(__FILE__, shell,
 		      "Get AllMgr: %08x %08x\n", shell, newman));
 
     return newman;
@@ -367,7 +367,7 @@ _XmInitProtocols(Widget w)
 
     _XmPushWidgetExtData(w, (XmWidgetExtData)newman, XmPROTOCOL_EXTENSION);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Init Protocols: %08x %08x\n", w, newman));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Init Protocols: %08x %08x\n", w, newman));
 
 #if 0
     XtAppAddActions(XtWidgetToApplicationContext(w),
@@ -438,7 +438,7 @@ _XmInstallProtocols(Widget w)
     Atom *protocols;
     int i, j;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmInstallProtocols\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmInstallProtocols\n"));
 
     if ((mgrs = __XmGetAllMgr(w)) == NULL)
     {
@@ -478,14 +478,14 @@ _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
     XmProtocol p;
     XmAnyCallbackStruct cd;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmProtocolHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmProtocolHandler\n"));
 
     cd.reason = XmCR_WM_PROTOCOLS;
     cd.event = evp;
 
     if (evp->type != ClientMessage)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmProtocolHandler(not a client message)\n"));
 	return;
     }
@@ -495,7 +495,7 @@ _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
 
     if ((mgrs = __XmGetAllMgr(w)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmProtocolHandler(couldn't find manager struct)\n"));
 
 	return;
@@ -503,7 +503,7 @@ _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
 
     if ((p = __XmFindProtocol(mgrs, property, protocol)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmProtocolHandler(couldn't find protocol)\n"));
 
 	return;
@@ -511,7 +511,7 @@ _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
 
     if (Protocol_Active(p))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmProtocolHandler(calling callbacks)\n"));
 
 	if (Protocol_PreHook(p).callback)
@@ -534,7 +534,7 @@ _XmProtocolHandler(Widget w, XtPointer client_data, XEvent *evp, Boolean *ctd)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmProtocolHandler(protocol not active)\n"));
     }
 }
@@ -548,7 +548,7 @@ XmActivateProtocol(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmActivateProtocol\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmActivateProtocol\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
@@ -572,7 +572,7 @@ XmDeactivateProtocol(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmDeactivateProtocol\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmDeactivateProtocol\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
@@ -612,11 +612,11 @@ XmAddProtocols(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmAddProtocols\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmAddProtocols\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, shell,
+	DEBUGOUT(_LtDebug(__FILE__, shell,
 			  "XmAddProtocols: Can't find Management structure:"
 			  " not a shell?\n"));
 	return;
@@ -705,11 +705,11 @@ XmAddProtocolCallback(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmAddProtocolCallback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmAddProtocolCallback\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, shell,
+	DEBUGOUT(_LtDebug(__FILE__, shell,
 		      "XmAddProtocolCallback: Can't find Management structure:"
 			  " not a shell?\n"));
 
@@ -754,11 +754,11 @@ XmRemoveProtocolCallback(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmRemoveProtocolCallback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmRemoveProtocolCallback\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, shell,
+	DEBUGOUT(_LtDebug(__FILE__, shell,
 		   "XmRemoveProtocolCallback: Can't find Management structure:"
 			  " not a shell?\n"));
 
@@ -803,7 +803,7 @@ XmRemoveProtocols(Widget shell,
 	XmProtocolMgr	  mgr;
     int i, mgr_slot, proto_slot;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmRemoveProtocols\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmRemoveProtocols\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
@@ -904,11 +904,11 @@ XmSetProtocolHooks(Widget shell,
     XmAllProtocolsMgr mgrs;
     XmProtocol p;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, shell, "XmSetProtocolHooks\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "XmSetProtocolHooks\n"));
 
     if ((mgrs = __XmGetAllMgr(shell)) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, shell,
+	DEBUGOUT(_LtDebug(__FILE__, shell,
 			  "XmSetProtocolHooks: Can't find Management structure:"
 			  " not a shell?\n"));
 
