@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ResConvert.c,v 1.115 2002/11/15 17:11:40 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ResConvert.c,v 1.118 2003/08/27 19:15:48 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.115 2002/11/15 17:11:40 dannybackx Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.118 2003/08/27 19:15:48 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -48,6 +48,7 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.115 2002/11/15 17:11:40 danny
 
 #if	USE_XFT
 #include <X11/Xft/Xft.h>
+#include <fontconfig/fontconfig.h>
 #endif
 
 enum
@@ -660,6 +661,12 @@ static XtConvertArgRec xftColorConvertArgs[] = {
 #define	XtRXftColor	"XftColor"
 #endif
 
+static char *filter_styles[] =
+{
+    "filter_none",
+    "filter_hidden_files"
+};
+
 #endif /* XmVERSION > 1 */
 
 
@@ -800,6 +807,8 @@ _XmRegisterConverters(void)
     REPTYPE_REGISTER_WITH_VALUES(XmRComboBoxType,
                 combobox_type, combobox_type_values);
 
+    REPTYPE_REGISTER(XmRFileFilterStyle, filter_styles);
+
     XmRepTypeInstallTearOffModelConverter();
 #endif /* XmVERSION > 1 */
 
@@ -1420,6 +1429,7 @@ _XmGetDefaultFontList(Widget w, unsigned char fontListType)
     XmFontList labelFontList = NULL;
     XmFontList buttonFontList = NULL;
     XmFontList textFontList = NULL;
+	XmFontListEntry	newEntry;
 
     Widget par = w;
     XmFontList fontlist, r;
@@ -1459,23 +1469,20 @@ _XmGetDefaultFontList(Widget w, unsigned char fontListType)
 		return r;
 	}
 
-	if (!textFontList)
-	{
-	    XmFontListEntry newEntry = XmFontListEntryLoad(XtDisplay(w),
-							   XmDEFAULT_FONT,
-							   XmFONT_IS_FONT,
-						       XmFONTLIST_DEFAULT_TAG);
-	    textFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
-	}
+	newEntry = XmFontListEntryLoad(XtDisplay(w),
+		XmDEFAULT_FONT,
+		XmFONT_IS_FONT,
+		XmFONTLIST_DEFAULT_TAG);
+	textFontList = XmFontListAppendEntry(NULL, newEntry);
+	XmFontListEntryFree(&newEntry);
 
 	if (textFontList == NULL) {
 		_XmWarning(w, "_XmGetDefaultFontList: textFontList NULL\n");
 	}
 
-	r = XmFontListCopy(textFontList);
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(textFontList) -> %p\n", r));
-	return r;
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(textFontList) -> %p\n",
+		textFontList));
+	return textFontList;
 
     case XmBUTTON_FONTLIST:
 	while ((par = XtParent(par)) != NULL)
@@ -1506,23 +1513,20 @@ _XmGetDefaultFontList(Widget w, unsigned char fontListType)
 		return r;
 	}
 
-	if (!buttonFontList)
-	{
-	    XmFontListEntry newEntry = XmFontListEntryLoad(XtDisplay(w),
-							   XmDEFAULT_FONT,
-							   XmFONT_IS_FONT,
-						       XmFONTLIST_DEFAULT_TAG);
-	    buttonFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
-	}
+	newEntry = XmFontListEntryLoad(XtDisplay(w),
+		XmDEFAULT_FONT,
+		XmFONT_IS_FONT,
+		XmFONTLIST_DEFAULT_TAG);
+	buttonFontList = XmFontListAppendEntry(NULL, newEntry);
+	XmFontListEntryFree(&newEntry);
 
 	if (buttonFontList == NULL) {
 		_XmWarning(w, "_XmGetDefaultFontList: buttonFontlist NULL\n");
 	}
 
-	r = XmFontListCopy(buttonFontList);
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(buttonFontList) -> %p\n", r));
-	return r;
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(buttonFontList) -> %p\n",
+		buttonFontList));
+	return buttonFontList;
 
     default:
     case XmLABEL_FONTLIST:
@@ -1556,23 +1560,20 @@ _XmGetDefaultFontList(Widget w, unsigned char fontListType)
 		return r;
 	}
 
-	if (!labelFontList)
-	{
-	    XmFontListEntry newEntry = XmFontListEntryLoad(XtDisplay(w),
-							   XmDEFAULT_FONT,
-							   XmFONT_IS_FONT,
-						       XmFONTLIST_DEFAULT_TAG);
-	    labelFontList = XmFontListAppendEntry(NULL, newEntry);
-            XmFontListEntryFree(&newEntry);
-	}
+	newEntry = XmFontListEntryLoad(XtDisplay(w),
+		XmDEFAULT_FONT,
+		XmFONT_IS_FONT,
+		XmFONTLIST_DEFAULT_TAG);
+	labelFontList = XmFontListAppendEntry(NULL, newEntry);
+	XmFontListEntryFree(&newEntry);
 
 	if (labelFontList == NULL) {
 		_XmWarning(w, "_XmGetDefaultFontList: labelFontList NULL\n");
 	}
 
-	r = XmFontListCopy(labelFontList);
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(labelFontList) -> %p\n", r));
-	return r;
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(labelFontList) -> %p\n",
+		labelFontList));
+	return labelFontList;
     }
 }
 
@@ -3024,6 +3025,8 @@ _XmRenditionFromResources(Display *dpy,
 		}
 	}
 #endif
+	if (searchlist)
+		XtFree(searchlist);
 	if (found && rp) {
 		*rp = r;
 		return True;
@@ -3116,6 +3119,8 @@ _XmCvtStringToRenderTable(Display *dpy,
 		count++;
 	}
 
+	XmRenditionFree(r);	/* ??? Leak removal ??? */
+
 	/*
 	 * The test below is a silly hack.
 	 */
@@ -3170,25 +3175,25 @@ _XmCvtStringToRenderTable(Display *dpy,
 			XftResult	res;
 			XftPattern	*p;
 
-			r->pattern = XftPatternCreate();
+			r->pattern = FcPatternCreate();
 			if (r->font_name)
-				XftPatternAddString(r->pattern, XFT_FAMILY, r->font_name);
+				FcPatternAddString(r->pattern, XFT_FAMILY, r->font_name);
 			if (r->font_foundry)
-				XftPatternAddString(r->pattern, XFT_FOUNDRY, r->font_foundry);
+				FcPatternAddString(r->pattern, XFT_FOUNDRY, r->font_foundry);
 			if (r->font_encoding)
-				XftPatternAddString(r->pattern, XFT_ENCODING, r->font_encoding);
+				FcPatternAddString(r->pattern, XFT_ENCODING, r->font_encoding);
 			if (r->font_style)
-				XftPatternAddString(r->pattern, XFT_STYLE, r->font_style);
+				FcPatternAddString(r->pattern, XFT_STYLE, r->font_style);
 			if (r->font_size)
-				XftPatternAddInteger(r->pattern, XFT_SIZE, r->font_size);
+				FcPatternAddInteger(r->pattern, XFT_SIZE, r->font_size);
 			if (r->pixel_size)
-				XftPatternAddInteger(r->pattern, XFT_PIXEL_SIZE, r->pixel_size);
+				FcPatternAddInteger(r->pattern, XFT_PIXEL_SIZE, r->pixel_size);
 			if (r->font_slant)
-				XftPatternAddInteger(r->pattern, XFT_SLANT, r->font_slant);
+				FcPatternAddInteger(r->pattern, XFT_SLANT, r->font_slant);
 			if (r->font_weight)
-				XftPatternAddInteger(r->pattern, XFT_WEIGHT, r->font_weight);
+				FcPatternAddInteger(r->pattern, XFT_WEIGHT, r->font_weight);
 			if (r->font_spacing)
-				XftPatternAddInteger(r->pattern, XFT_SPACING, r->font_spacing);
+				FcPatternAddInteger(r->pattern, XFT_SPACING, r->font_spacing);
 
 			p = XftFontMatch(XtDisplay(w), 0, r->pattern, &res);
 			r->xft_font = XftFontOpenPattern(XtDisplay(w), p);
