@@ -1,6 +1,6 @@
 /**
  *
- * $Id: SeparatoG.c,v 1.21 2001/09/13 13:34:13 amai Exp $
+ * $Id: SeparatoG.c,v 1.22 2003/09/15 19:11:07 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: SeparatoG.c,v 1.21 2001/09/13 13:34:13 amai Exp $";
+static const char rcsid[] = "$Id: SeparatoG.c,v 1.22 2003/09/15 19:11:07 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -621,7 +621,8 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = False;
+	Boolean		refresh_needed = False;
+	XGCValues	gcv;
 
     G_TraversalOn(new_w) = False;
     if (XmIsRowColumn(XtParent(new_w)) &&
@@ -690,7 +691,9 @@ set_values(Widget old, Widget request, Widget new_w,
 	refresh_needed = True;
     }
 
-    if (XmParentForeground(new_w) != XmParentForeground(old) ||
+	/* See bug #772755 : need to query the old widget's values */
+	XGetGCValues(XtDisplay(old), LabG_NormalGC(old), GCForeground, &gcv);
+	if (XmParentForeground(new_w) != gcv.foreground ||
 	XmParentBackground(new_w) != XmParentBackground(old) ||
 	((SEPG_SeparatorType(new_w) == XmSINGLE_DASHED_LINE ||
 	  SEPG_SeparatorType(new_w) == XmDOUBLE_DASHED_LINE) ^
