@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.123 2002/11/15 17:00:54 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.128 2003/07/18 19:23:50 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.123 2002/11/15 17:00:54 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.128 2003/07/18 19:23:50 amai Exp $";
 
 /* Do NOT use this (USE_XT_GC) :
  * it requires setting all the dynamic GC fields before every use of
@@ -555,10 +555,30 @@ GCPixmap(XmTextWidget tw)
 
 		XSetForeground(display, gc, 1);
 
-		XDrawLine(display, Out_CursorIBeam(o), gc, 2, 1, 2, height - 2);
-		XDrawLine(display, Out_CursorIBeam(o), gc, 0, 0, 4, 0);
-		XDrawLine(display, Out_CursorIBeam(o), gc, 0, height - 1,
-			4, height - 1);
+		if (Text_InputData(w)->overstrike) {
+			/* Overwrite cursor */
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				0, 0,
+				0, height - 1);
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				0, height - 1,
+				width - 1, height - 1);
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				width - 1, height - 1,
+				width - 1, 0);
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				width - 1, 0,
+				0, 0);
+		} else {
+			/* I-beam */
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				2, 1, 2, height - 2);
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				0, 0, 4, 0);
+			XDrawLine(display, Out_CursorIBeam(o), gc,
+				0, height - 1,
+				4, height - 1);
+		}
 
 		XSetLineAttributes(display, gc, 0, LineOnOffDash, CapRound, JoinRound);
 		XSetDashes(display, gc, 0, &dots[1], (int)dots[0]);
@@ -904,21 +924,22 @@ _XmTextNextX(XmTextWidget w, int x, char *ptr, int len)
 	    x = 0;
 	} else {
 	    if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT) {
-                x += XTextWidth(fs, ptr, len);
+                x += XTextWidth(fs, ptr, 1);
             } else if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONTSET) {
-                XmbTextExtents((XFontSet)Out_FontList(o)->renditions[0]->font, ptr, len, &ink, &log);
+                XmbTextExtents((XFontSet)Out_FontList(o)->renditions[0]->font, ptr, 1, &ink, &log);
                 x += log.width;
 #ifdef	USE_XFT
             } else if (Out_XftFont(o)) {
 	    	XGlyphInfo	ext;
 		XftTextExtents8(XtDisplay((Widget)w), Out_XftFont(o),
-			ptr, len, &ext);
+			ptr, 1, &ext);
 		x += ext.width;
 #endif
 	    } else {
 		/* ??? */
 	    }
 
+#if 0
             break;
 
 	    if (c < fs->min_char_or_byte2 || c > fs->max_char_or_byte2)
@@ -945,6 +966,7 @@ _XmTextNextX(XmTextWidget w, int x, char *ptr, int len)
 	    }
 	    else
 		x += fs->max_bounds.width;
+#endif
 	}
 
 	ptr++;
@@ -1133,14 +1155,12 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 	bg = XtBackground(w);
 
 	/* Only change the GC if we need to */
-	if (highlight == XmHIGHLIGHT_SELECTED && !Out_DrawGCInverted(o)) {
+	if (highlight == XmHIGHLIGHT_SELECTED) {
 		fg = XtBackground(w);
 		bg = Prim_Foreground(w);
-		Out_DrawGCInverted(o) = True;
-	} else if (Out_DrawGCInverted(o) && highlight != XmHIGHLIGHT_SELECTED) {
+	} else {
 		fg = Prim_Foreground(w);
 		bg = XtBackground(w);
-		Out_DrawGCInverted(o) = False;
 	}
 
 	while (len > 0 && *ptr) {
@@ -1170,8 +1190,8 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 				v.background = fg;
 				XChangeGC(XtDisplay(w), Out_DrawGC(o), mask, &v);
 				XFillRectangle(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
-					x + xoff, y - o->font_ascent,
-					piecewidth, y + o->font_descent);
+					x + xoff, y - Out_FontAscent(o),
+					piecewidth, y + Out_FontDescent(o));
 
 				v.background = bg;
 				v.foreground = fg;
@@ -1449,6 +1469,26 @@ CursorInit(XmTextWidget w)
 }
 
 
+void
+_XmCursorOverstrike(Widget w)
+{
+    OutputData o = Text_OutputData(w);
+    /* These change the GC !! (Danny) */
+    if (Out_HasFocus(o)) {
+	GCPixmap(w);
+	if (Text_InputData(w)->overstrike) {
+		XSetStipple(XtDisplay((Widget)w), Out_CursorGC(o),
+			Out_CursorIBeam(o));
+	} else {
+		XSetStipple(XtDisplay((Widget)w), Out_CursorGC(o),
+			Out_CursorIBeam(o));
+	}
+    } else {
+	XSetStipple(XtDisplay((Widget)w), Out_CursorGC(o),
+		    Out_CursorStipple(o));
+    }
+}
+
 static void
 CursorSet(XmTextWidget w, Boolean focus)
 {
@@ -1457,13 +1497,10 @@ CursorSet(XmTextWidget w, Boolean focus)
     Out_HasFocus(o) = focus;
 
     /* These change the GC !! (Danny) */
-    if (focus)
-    {
+    if (focus) {
 	XSetStipple(XtDisplay((Widget)w), Out_CursorGC(o),
-		    Out_CursorIBeam(o));
-    }
-    else
-    {
+		Out_CursorIBeam(o));
+    } else {
 	XSetStipple(XtDisplay((Widget)w), Out_CursorGC(o),
 		    Out_CursorStipple(o));
     }
@@ -1544,8 +1581,14 @@ CursorDrawIBeam(XmTextWidget w, int x, int y)
     XSetTSOrigin(XtDisplay((Widget)w), Out_CursorGC(o),
 		 x - 2, y);
 
-    XFillRectangle(XtDisplay((Widget)w), XtWindow((Widget)w), Out_CursorGC(o),
-		   x - 2, y, Out_CursorWidth(o), Out_CursorHeight(o));
+    if (Text_InputData(w)->overstrike) {
+    } else {
+    }
+
+	XFillRectangle(XtDisplay((Widget)w), XtWindow((Widget)w),
+		Out_CursorGC(o),
+		x - 2, y,
+		Out_CursorWidth(o), Out_CursorHeight(o));
 }
 
 
