@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.84 2002/04/20 18:32:33 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.85 2002/07/04 18:45:51 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.84 2002/04/20 18:32:33 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.85 2002/07/04 18:45:51 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -615,6 +615,10 @@ CreateSelectGC(Widget w)
 
 #if XmVERSION > 1
     values.foreground = TBG_UnselectColor(w);
+
+    DEBUGOUT(_LtDebug(__FILE__, w, "CreateSelectGC: unselect color %p\n",
+	TBG_UnselectColor(w)));
+
     TBG_UnselectGC(w) = XtGetGC(w, mask, &values);
 #endif
 }
@@ -2307,8 +2311,6 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 static void
 _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 {
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmUnselectColorDefault\n"));
-
 #if XmVERSION > 1
 	/*
 	 * XmNunselectColor
@@ -2320,10 +2322,18 @@ _XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
 	 */
 	val->size = sizeof(Pixel);
 	val->addr = (XtPointer)&CoreBackground(w);
+
+#define XmParentBackgroundPixel(w) (((XmManagerWidget) \
+        (((XmGadget)(w))->object.parent))->core.background_pixel)
+
+	val->addr = (XtPointer)&XmParentBackgroundPixel(w);
 #if 0
 	if (DefaultDepth(XtDisplay(w), 0) == 1) {	/* Mono */
 	} else {					/* Colour */
 	}
 #endif
 #endif
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmUnselectColorDefault(%p)\n",
+		*(Pixel *)(val->addr)));
 }
