@@ -1,6 +1,6 @@
 /**
  *
- * $Id: VaSimple.c,v 1.14 2001/05/14 19:46:11 amai Exp $
+ * $Id: VaSimple.c,v 1.16 2001/08/02 19:51:49 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -50,7 +50,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: VaSimple.c,v 1.14 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Id: VaSimple.c,v 1.16 2001/08/02 19:51:49 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -288,7 +288,7 @@ _XmTypedArgToArg(Widget widget, XtTypedArgList typed_arg, ArgList arg_return,
     to_val.addr = NULL;
     from_val.size = typed_arg->size;
     if ((strcmp(typed_arg->type, XtRString) == 0) ||
-	(typed_arg->size > sizeof(XtArgVal)))
+	(typed_arg->size > (int)sizeof(XtArgVal)))
     {
 	from_val.addr = (XPointer)typed_arg->value;
     }
@@ -706,7 +706,7 @@ XmVaCreateSimpleCheckBox(Widget parent,
     va_list var;
     Widget rc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimpleCheckBox();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimpleCheckBox();\n"));
 
 #ifdef SIMPLE_WALKUP
     while (parent && !XtIsComposite(parent))
@@ -779,7 +779,7 @@ XmVaCreateSimpleMenuBar(Widget parent,
     va_list var;
     Widget rc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimpleMenuBar();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimpleMenuBar();\n"));
 
 #ifdef SIMPLE_WALKUP
     while (parent && !XtIsComposite(parent))
@@ -845,7 +845,7 @@ XmVaCreateSimpleOptionMenu(Widget parent,
     va_list var;
     Widget rc = NULL;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimpleOptionMenu();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimpleOptionMenu();\n"));
 
 #ifdef SIMPLE_WALKUP
     while (parent && !XtIsComposite(parent))
@@ -912,7 +912,7 @@ XmVaCreateSimplePopupMenu(Widget parent,
     va_list var;
     Widget rc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimplePopupMenu();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimplePopupMenu();\n"));
 
 #ifdef SIMPLE_WALKUP
 	/*
@@ -989,7 +989,7 @@ XmVaCreateSimplePulldownMenu(Widget parent,
     Widget rc;
 
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimplePulldownMenu();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimplePulldownMenu();\n"));
 
 #ifdef SIMPLE_WALKUP
     while (parent && !XtIsComposite(parent))
@@ -1058,7 +1058,7 @@ XmVaCreateSimpleRadioBox(Widget parent,
     va_list var;
     Widget rc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, parent, "XmVaCreateSimpleRadioBox();\n"));
+    DEBUGOUT(_LtDebug(__FILE__, parent, "XmVaCreateSimpleRadioBox();\n"));
 
 #ifdef SIMPLE_WALKUP
     while (parent && !XtIsComposite(parent))
