@@ -1,8 +1,10 @@
 /*
+ * $Header: /cvsroot/lesstif/lesstif/test/Xm/misc/test15.c,v 1.4 2002/04/17 16:22:00 amai Exp $
  * Produce a C source file that contains the Motif private error
  * messages.
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
 
@@ -378,12 +380,12 @@ struct {
 	{ NULL, NULL }
 };
 
-main()
+int main(int argc, char *argv[])
 {
 	int	i;
 	char	*p;
 
-	printf("/* $Id: test15.c,v 1.3 2000/09/15 03:45:37 rwscott Exp $ */\n");
+	printf("/* $Id: test15.c,v 1.4 2002/04/17 16:22:00 amai Exp $ */\n");
 	printf("/* This is the output of LESSTIF/test/Xm/test15.c */\n");
 	printf("\n");
 	printf("\n");
