@@ -1,5 +1,5 @@
-/* $Id: test54.c,v 1.2 2000/08/29 21:59:21 dannybackx Exp $ */
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/rowcolumn/test54.c,v 1.4 2002/02/02 11:43:11 amai Exp $
+ *
  *
  * Test indicating problems with menu focus handling code.
  * JAC, May 10, 1999.
@@ -10,7 +10,14 @@
  */
 
 #include <stdlib.h>
-#include <Xm/XmAll.h>
+
+#include <Xm/Xm.h>
+#include <Xm/CascadeB.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Separator.h>
+#include <Xm/ToggleB.h>
+#include <Xm/TearOffBP.h> /* for xmTearOffButtonWidgetClass */
+
 
 /*************************************************************
  *
@@ -69,7 +76,6 @@ typedef struct {
 
 
 
-#include <Xm/TearOffBP.h> /* for xmTearOffButtonWidgetClass */
 
 static void DopupCB(Widget w, XtPointer client, XtPointer call);
 void GXMakeMenu(char *title, Widget menu, GXMenuStruct * menulist, int
@@ -312,7 +318,7 @@ void GXMakeMenu(char *title, Widget menu, GXMenuStruct * menulist, int
 					    menu, wargs,
 					    defargcnt),(int)NULL);
 	    switch ((int) menulist[i].func) {
-	    case NULL:
+	    case 0:
 		break;
 	    case (int) GX_INSENSITIVE:
 		XtSetSensitive(w, FALSE);
@@ -336,7 +342,7 @@ void GXMakeMenu(char *title, Widget menu, GXMenuStruct * menulist, int
 					      menu, wargs,
 					      defargcnt + n),(int)NULL);
 	    switch ((int) menulist[i].func) {
-	    case NULL:
+	    case 0:
 		break;
 	    case (int) GX_INSENSITIVE:
 		XtSetSensitive(w, FALSE);
